@@ -5,6 +5,7 @@
 */
 
 #include "filterbalsa.h"
+using namespace Qt::Literals::StringLiterals;
 
 #include <KLocalizedString>
 #include <QFileDialog>
@@ -20,7 +21,7 @@ public:
 /** Default constructor. */
 FilterBalsa::FilterBalsa()
     : Filter(i18n("Import Balsa Local Mails and Folder Structure"),
-             QStringLiteral("Laurent Montel"),
+             u"Laurent Montel"_s,
              i18n("<p><b>Balsa import filter</b></p>"
                   "<p>Select the base directory of your local Balsa mailfolder (usually ~/mail/).</p>"
                   "<p>Since it is possible to recreate the folder structure, the folders "
@@ -68,13 +69,13 @@ void FilterBalsa::import()
 void FilterBalsa::processDirectory(const QString &path)
 {
     QDir dir(path);
-    const QStringList rootSubDirs = dir.entryList(QStringList(QStringLiteral("*")), QDir::Dirs | QDir::Hidden, QDir::Name);
+    const QStringList rootSubDirs = dir.entryList(QStringList(u"*"_s), QDir::Dirs | QDir::Hidden, QDir::Name);
     QStringList::ConstIterator end = rootSubDirs.constEnd();
     for (QStringList::ConstIterator filename = rootSubDirs.constBegin(); filename != end; ++filename) {
         if (filterInfo()->shouldTerminate()) {
             break;
         }
-        if (!(*filename == QLatin1Char('.') || *filename == QLatin1StringView(".."))) {
+        if (!(*filename == u'.' || *filename == QLatin1StringView(".."))) {
             filterInfo()->setCurrent(0);
             importDirContents(dir.filePath(*filename));
             filterInfo()->setOverall((d->mTotalDir > 0) ? (int)((float)d->mImportDirDone / d->mTotalDir * 100) : 0);
@@ -94,7 +95,7 @@ void FilterBalsa::importMails(const QString &maildir)
      * If the user only select homedir no import needed because
      * there should be no files and we surely import wrong files.
      */
-    if (mailDir() == QDir::homePath() || mailDir() == (QDir::homePath() + QLatin1Char('/'))) {
+    if (mailDir() == QDir::homePath() || mailDir() == (QDir::homePath() + u'/')) {
         filterInfo()->addErrorLogEntry(i18n("No files found for import."));
     } else {
         filterInfo()->setOverall(0);
@@ -146,7 +147,7 @@ void FilterBalsa::importFiles(const QString &dirName)
     bool generatedPath = false;
 
     QDir importDir(dirName);
-    const QStringList files = importDir.entryList(QStringList(QStringLiteral("[^\\.]*")), QDir::Files, QDir::Name);
+    const QStringList files = importDir.entryList(QStringList(u"[^\\.]*"_s), QDir::Files, QDir::Name);
     int currentFile = 1;
     int numFiles = files.size();
     QStringList::ConstIterator filesEnd(files.constEnd());
@@ -163,21 +164,21 @@ void FilterBalsa::importFiles(const QString &dirName)
                 _path = i18nc("define folder name where we import evolution mails", "Evolution-Import");
                 QString _tmp = dir.filePath(*mailFile);
                 _tmp.remove(mailDir(), Qt::CaseSensitive);
-                QStringList subFList = _tmp.split(QLatin1Char('/'), Qt::SkipEmptyParts);
+                QStringList subFList = _tmp.split(u'/', Qt::SkipEmptyParts);
                 QStringList::ConstIterator end(subFList.end());
                 for (QStringList::ConstIterator it = subFList.constBegin(); it != end; ++it) {
                     QString _cat = *it;
                     if (!(_cat == *mailFile)) {
-                        if (_cat.startsWith(QLatin1Char('.'))) {
+                        if (_cat.startsWith(u'.')) {
                             _cat.remove(0, 1);
                         }
                         // Evolution store inbox as "."
-                        if (_cat.startsWith(QLatin1Char('.'))) {
-                            _cat.replace(0, 1, QStringLiteral("Inbox/"));
+                        if (_cat.startsWith(u'.')) {
+                            _cat.replace(0, 1, u"Inbox/"_s);
                         }
 
-                        _path += QLatin1Char('/') + _cat;
-                        _path.replace(QLatin1Char('.'), QLatin1Char('/'));
+                        _path += u'/' + _cat;
+                        _path.replace(u'.', u'/');
                     }
                 }
                 if (_path.endsWith(QLatin1StringView("cur"))) {
@@ -205,16 +206,16 @@ MailImporter::MessageStatus FilterBalsa::statusFromFile(const QString &filename)
     const int statusIndex = filename.indexOf(QLatin1StringView(":2,"));
     if (statusIndex != -1) {
         const QString statusStr = filename.right(filename.length() - statusIndex - 3);
-        if (statusStr.contains(QLatin1Char('S'))) {
+        if (statusStr.contains(u'S')) {
             status.setRead(true);
         }
-        if (statusStr.contains(QLatin1Char('F'))) {
+        if (statusStr.contains(u'F')) {
             // TODO
         }
-        if (statusStr.contains(QLatin1Char('R'))) {
+        if (statusStr.contains(u'R')) {
             status.setReplied(true);
         }
-        if (statusStr.contains(QLatin1Char('P'))) {
+        if (statusStr.contains(u'P')) {
             status.setForwarded(true);
         }
     }
